@@ -17,6 +17,7 @@ from unittest import mock
 import sushy
 from sushy import exceptions
 from sushy.resources.chassis import chassis
+from sushy.resources import constants as res_cons
 from sushy.resources.manager import manager
 from sushy.resources.manager import virtual_media
 from sushy.resources.system import system
@@ -26,7 +27,7 @@ from sushy.tests.unit import base
 class ManagerTestCase(base.TestCase):
 
     def setUp(self):
-        super(ManagerTestCase, self).setUp()
+        super().setUp()
         self.conn = mock.Mock()
         with open('sushy/tests/unit/json_samples/manager.json') as f:
             self.json_doc = json.load(f)
@@ -261,7 +262,7 @@ class ManagerTestCase(base.TestCase):
         self.assertIsInstance(vrt_media, virtual_media.VirtualMediaCollection)
 
         # On refreshing the manager instance...
-        with open('sushy/tests/unit/json_samples/manager.json', 'r') as f:
+        with open('sushy/tests/unit/json_samples/manager.json') as f:
             self.conn.get.return_value.json.return_value = json.loads(f.read())
 
         self.manager.invalidate()
@@ -304,11 +305,50 @@ class ManagerTestCase(base.TestCase):
         self.assertEqual(
             '/redfish/v1/Chassis/1U', actual_chassis[0].path)
 
+    def test_ethernet_interfaces(self):
+        self.conn.get.return_value.json.reset_mock()
+        eth_coll_return_value = None
+        eth_return_value = None
+        with open('sushy/tests/unit/json_samples/'
+                  'manager_ethernet_interfaces_collection.json') as f:
+            eth_coll_return_value = json.load(f)
+        with open('sushy/tests/unit/json_samples/'
+                  'manager_ethernet_interfaces.json') as f:
+            eth_return_value = json.load(f)
+
+        self.conn.get.return_value.json.side_effect = [eth_coll_return_value,
+                                                       eth_return_value]
+
+        actual_macs = self.manager.ethernet_interfaces.summary
+        expected_macs = (
+            {'B4:AC:57:49:90:CA': res_cons.State.ENABLED})
+        self.assertEqual(expected_macs, actual_macs)
+
+
+class ManagerWithoutVirtualMedia(base.TestCase):
+
+    def setUp(self):
+        super().setUp()
+        self.conn = mock.Mock()
+        with open('sushy/tests/unit/json_samples/'
+                  'managerv1_18.json') as f:
+            self.json_doc = json.load(f)
+
+        self.conn.get.return_value.json.return_value = self.json_doc
+
+        self.manager = manager.Manager(self.conn, '/redfish/v1/Managers/BMC',
+                                       redfish_version='1.0.2')
+
+    def test_no_virtual_media_attr(self):
+        with self.assertRaisesRegex(
+            exceptions.MissingAttributeError, 'attribute VirtualMedia'):
+            self.manager.virtual_media
+
 
 class ManagerCollectionTestCase(base.TestCase):
 
     def setUp(self):
-        super(ManagerCollectionTestCase, self).setUp()
+        super().setUp()
         self.conn = mock.Mock()
         with open('sushy/tests/unit/json_samples/'
                   'manager_collection.json') as f:
