@@ -36,7 +36,7 @@ from sushy.tests.unit import base
 class SystemTestCase(base.TestCase):
 
     def setUp(self):
-        super(SystemTestCase, self).setUp()
+        super().setUp()
         self.conn = mock.Mock()
         self.conn.get.return_value.headers = {'Allow': 'GET,HEAD'}
         with open('sushy/tests/unit/json_samples/system.json') as f:
@@ -339,8 +339,7 @@ class SystemTestCase(base.TestCase):
     def test_set_system_boot_options_invalid_enabled(self):
         with self.assertRaisesRegex(
             exceptions.InvalidParameterValueError,
-            '"enabled" value.*{0}'.format(
-                list(sushy.BootSourceOverrideEnabled))):
+            f'"enabled" value.*{list(sushy.BootSourceOverrideEnabled)}'):
 
             self.sys_inst.set_system_boot_options(
                 sushy.BootSource.HDD,
@@ -504,6 +503,35 @@ class SystemTestCase(base.TestCase):
                            'HttpBootUri': 'http://test.lan/test_image.iso'}},
             etag=mock.ANY)
 
+    def test_set_system_boot_options_httpboot_settings(self):
+
+        with open('sushy/tests/unit/json_samples/settings-nokia.json') as f:
+            settings_obj = json.load(f)
+
+        self.json_doc.update(settings_obj)
+        self.sys_inst._parse_attributes(self.json_doc)
+
+        with open('sushy/tests/unit/json_samples/'
+                  'settings-body-nokia.json') as f:
+            settings_body = json.load(f)
+
+        get_settings = mock.MagicMock(headers={'ETag': '"3d7b838291941d"'})
+        get_settings.json.return_value = settings_body
+        get_system = mock.MagicMock(headers={'ETag': '"222"'})
+        self.conn.get.side_effect = [get_settings, get_system]
+
+        self.sys_inst.set_system_boot_options(
+            sushy.BootSource.UEFI_HTTP,
+            enabled=sushy.BootSourceOverrideEnabled.ONCE,
+            http_boot_uri='http://test.lan/test_image.iso'
+            )
+        self.sys_inst._conn.patch.assert_called_once_with(
+            '/redfish/v1/Systems/Self/SD',
+            data={'Boot': {'BootSourceOverrideTarget': 'UefiHttp',
+                           'BootSourceOverrideEnabled': 'Once',
+                           'HttpBootUri': 'http://test.lan/test_image.iso'}},
+            etag=mock.ANY)
+
     def test_set_system_boot_options_httpboot(self):
         self.sys_inst.set_system_boot_options(
             sushy.BootSource.UEFI_HTTP,
@@ -593,8 +621,7 @@ class SystemTestCase(base.TestCase):
     def test_set_system_boot_source_invalid_enabled(self):
         with self.assertRaisesRegex(
             exceptions.InvalidParameterValueError,
-            '"enabled" value.*{0}'.format(
-                list(sushy.BootSourceOverrideEnabled))):
+            f'"enabled" value.*{list(sushy.BootSourceOverrideEnabled)}'):
 
             self.sys_inst.set_system_boot_source(
                 sushy.BootSource.HDD,
@@ -890,6 +917,33 @@ class SystemTestCase(base.TestCase):
         self.assertEqual(
             '/redfish/v1/Managers/BMC', actual_managers[0].path)
 
+    def test_managers_retry(self):
+        with open('sushy/tests/unit/json_samples/'
+                  'system_managedby_missing_manager_present.json') as f:
+            settings_obj = json.load(f)
+        self.json_doc.update(settings_obj)
+        self.sys_inst._parse_attributes(self.json_doc)
+
+        # | GIVEN |
+        with open('sushy/tests/unit/json_samples/'
+                  'manager.json') as f:
+            self.conn.get.return_value.json.return_value = json.load(f)
+
+        # | WHEN & THEN |
+        actual_managers = self.sys_inst.managers
+        self.assertIsInstance(actual_managers[0], manager.Manager)
+        self.assertEqual(
+            '/redfish/v1/Managers/BMC', actual_managers[0].path)
+
+    def test_managers_missing_ref(self):
+        # | GIVEN |
+        del self.json_doc['Links']['ManagedBy']
+
+        # | WHEN & THEN |
+        with self.assertRaisesRegex(
+            exceptions.MissingAttributeError, 'attribute Links/ManagedBy'):
+            self.sys_inst.managers
+
     def test_chassis(self):
         # | GIVEN |
         with open('sushy/tests/unit/json_samples/'
@@ -920,7 +974,7 @@ class SystemTestCase(base.TestCase):
 class SystemWithVirtualMedia(base.TestCase):
 
     def setUp(self):
-        super(SystemWithVirtualMedia, self).setUp()
+        super().setUp()
         self.conn = mock.Mock()
         with open('sushy/tests/unit/json_samples/'
                   'systemv1_20.json') as f:
@@ -972,7 +1026,7 @@ class SystemWithVirtualMedia(base.TestCase):
         self.assertIsInstance(actual_virtual_media,
                               virtual_media.VirtualMediaCollection)
 
-        with open('sushy/tests/unit/json_samples/systemv1_20.json', 'r') as f:
+        with open('sushy/tests/unit/json_samples/systemv1_20.json') as f:
             self.conn.get.return_value.json.return_value = json.loads(f.read())
 
         self.sys_inst.invalidate()
@@ -994,7 +1048,7 @@ class SystemWithVirtualMedia(base.TestCase):
 class SystemCollectionTestCase(base.TestCase):
 
     def setUp(self):
-        super(SystemCollectionTestCase, self).setUp()
+        super().setUp()
         self.conn = mock.Mock()
         with open('sushy/tests/unit/json_samples/'
                   'system_collection.json') as f:
